==> patch-4.1.5-ONex-OMS-pro-source-PHP5.3.tar.gz: ShopexErp/app/ome/lib/finder/reship.php <==
<?php
class ome_finder_reship{
    function __construct($app){
        $this->app = $app;
        if($_GET['app'] == 'console' ){
            unset($this->column_edit);
        }
    }
    var $addon_cols = 'need_sv,is_check,archive,source,order_id,return_id';

    var $detail_basic = "退货单详情";

    function detail_basic($reship_id){
        $basicMaterialExtObj = app::get('material')->model('basic_material_ext');
        $render = app::get('ome')->render();
        $oReship = app::get('ome')->model('reship');
        $detail = $oReship->getCheckinfo($reship_id);

        $oDesktop          = app::get('desktop')->model('users');
        $desktop_detail    = $oDesktop->dump(array('user_id'=>$detail['op_id']), 'name');
        $detail['op_name'] = $desktop_detail['name'];

        if($detail['is_check'] == '3') $detail['is_check'] = '1';

        $cols = $oReship->_columns();
        $detail['is_check'] = $cols['is_check']['type'][$detail['is_check']];

        $reason = unserialize($detail['reason']);
        $detail['check_memo'] = $reason['check'];

        # 售后问题类型
        if ($detail['problem_id']) {
            $detail['problem_name'] = app::get('ome')->model('return_product_problem')->getCatName($detail['problem_id']);
        }

        $render->pagedata['detail'] = $detail;

        #[换货]关联的销售物料的类型
        if($detail['return_type'] == 'change'){
            $reshipObjects    = app::get('ome')->model('reship_objects');
            $temp_data    = $reshipObjects->getList('obj_id, obj_type', array('reship'=>$reship_id));
            $reship_objects    = array();
            if($temp_data){
                foreach ($temp_data as $key => $val){
                    $reship_objects[$val['obj_id']]    = $val['obj_type'];
                }
            }
            unset($temp_data);
        }

        #退换货明细
        $reship_item = $oReship->getItemList($reship_id);
        foreach ($reship_item as $key => $value){
            $spec_info    = $basicMaterialExtObj->dump(array('bm_id'=>$value['product_id']), '*');
            $reship_item[$key]['spec_info'] = $spec_info['specifications'];
            $reship_item[$key]['specifications'] = $spec_info['specifications'];
            #换货的销售物料类型
            if($value['obj_id']){
                $reship_item[$key]['item_type']    = $reship_objects[$value['obj_id']];
            }
            $recover[$value['return_type']][] = $reship_item[$key];
        }

        $render->pagedata['items'] = $recover;
        return $render->fetch('admin/reship/detail.html');
    }

    var $detail_log = "操作日志";
    function detail_log($reship_id){
        $render = app::get('ome')->render();
        $oOperation_log = app::get('ome')->model('operation_log');
        $render->pagedata['log'] = $oOperation_log->read_log(array('obj_type'=>'reship@ome','obj_id'=>$reship_id),0,20,'log_id desc');
        return $render->fetch('admin/reship/detail_log.html');
    }

    var $detail_acceptreturned = "收货记录";
    function detail_acceptreturned($reship_id){
        $render = app::get('ome')->render();
        $Oreship = app::get('ome')->model('reship');
        $Oreturn_process = app::get('ome')->model('return_process');
        $return = $Oreturn_process->getList('process_data',array('reship_id'=>$reship_id));
        $process_data = unserialize($return[0]['process_data']);
        $process_data['shipdaofu'] = $process_data['shipdaofu']==1?'是':'否';
        if($process_data['shipcompany']){
            $oDc = app::get('ome')->model('dly_corp');
            $dc_data = $oDc->dump($process_data['shipcompany']);
            $process_data['shipcompany'] = !empty($dc_data['name'])?$dc_data['name']:'';
        }
        $Oreason = $Oreship->dump(array('reship_id'=>$reship_id),'reason');
        $Oreason['reason'] = unserialize($Oreason['reason']);
        $p = strpos($Oreason['reason'],'#收货原因#');

        if($p!==false){
           $reason = str_replace('#收货原因#','',$Oreason['reason']);
           $process_data['refuse_memo'] = $reason;
        }

        $render->pagedata['detail'] = $process_data;
        return $render->fetch('admin/reship/detail_acceptreturned.html');
    }

    var $detail_returnedsv = "质检记录";
    function detail_returnedsv($reship_id){
        $render = app::get('ome')->render();
        $Oreship = app::get('ome')->model('reship');
        $Oreturn_process = app::get('ome')->model('return_process');
        $oProblem = app::get('ome')->model('return_product_problem');
        $oBranch = app::get('ome')->model('branch');

        $return = $Oreturn_process->getList('process_data,memo',array('reship_id'=>$reship_id));

        $Oreturn_process_items = app::get('ome')->model('return_process_items');
        $process_items = $Oreturn_process_items->getList('bn,memo,store_type,branch_id,num',array('is_check'=>'true','reship_id'=>$reship_id));

        $process_data = unserialize($return[0]['process_data']);
        $process_data['shipdaofu'] = $process_data['shipdaofu']==1?'是':'否';
        $Oreason = $Oreship->dump(array('reship_id'=>$reship_id),'reason,is_check,need_sv');

        $process_data['reason'] = unserialize($Oreason['reason']);

        foreach($process_items as $k=>$v){
           $process_items[$k]['store_type'] = $oProblem->get_store_type($process_items[$k]['store_type']);
           $branch = $oBranch->db->selectrow("SELECT name from sdb_ome_branch WHERE branch_id=".$process_items[$k]['branch_id']);
           $process_items[$k]['branch_id'] = $branch['name'];
        }

        $render->pagedata['memo'] = $return[0]['memo'];
        $render->pagedata['process_items'] = $process_items;
        $render->pagedata['detail'] = $process_data;

        $s = kernel::single('ome_reship')->is_precheck_reship($Oreason['is_check'],$Oreason['need_sv']);
        if ($s) {
            $render->pagedata['memo'] = '质检异常';
        }

        return $render->fetch('admin/reship/detail_returnsv.html');
    }


    var $column_edit = "操作";
    var $column_edit_width = "200";
    function column_edit($row){
        $oReship = app::get('ome')->model('reship');
        $reship_items= $oReship->dump($row['reship_id'],'reship_bn');
        $is_check = $row[$this->col_prefix.'is_check'];
		if ($is_check == '11' || $is_check=='9'){
			$edit_title = '最终收货';
		}else{
			$edit_title = '编辑';
		}
        $precheck = kernel::single('ome_reship')->is_precheck_reship($row[$this->col_prefix.'is_check'],$row[$this->col_prefix.'need_sv']);

        $check = '<a target="dialog::{width:1200,height:546,title:\'审核退换货单号:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=check&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">'.($precheck ? '最终收货' : '审核').'</a>  ';

        $anti_check = '  <a target="dialog::{width:250,height:100,title:\'反审核退换货单号:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=anti_check&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">反审核</a>  ';

        $edit ='  <a target="dialog::{width:1200,height:546,title:\'编辑退换货单:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=edit&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">'.$edit_title.'</a>  ';

        $accept_returned = '  <a target="dialog::{width:1200,height:546,title:\'收货退换货单:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=accept_returned&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">收货</a>  ';

        $cancel = '  <a target="dialog::{width:280,height:100,title:\'取消退换货单号:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=do_cancel&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">取消</a>  ';

        $doback = '  <a target="dialog::{width:280,height:100,title:\'退换货单号:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=do_back&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">退回</a>';

        $quality_check = '  <a target="dialog::{width:1200,height:546,title:\'质检退换货单:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_sv&act=edit&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">收货/质检</a>';

       $permissions = array(
            'check'         => 'aftersale_rchange_check',
            'anti_check'    => 'aftersale_rchange_recheck',
            'edit'          => 'aftersale_rchange_edit',
            'cancel'        => 'aftersale_rchange_refuse',
            'doback'        => 'aftersale_rchange_back',
            'quality_check' => 'aftersale_rchange_sv'
       );
        if(!kernel::single('desktop_user')->is_super()){
            $returnLib = kernel::single('ome_return');
            foreach ($permissions as $key=>$permission) {
                $has_permission = $returnLib->chkground('aftersale_center','',$permission);
                // $has_permission = kernel::single('desktop_user')->has_permission($permission);
                if (!$has_permission) {
                    $$key = '';
                }
            }
        }

        switch($row[$this->col_prefix.'is_check']){
            case '0':
			case '12':
               $cols = $check.$edit.$cancel;
            break;
            case '1':
              if($_GET['flt'] == 'process_list'){
                $cols = $quality_check;
              }else{
                $cols.= $cancel;
              }
            break;
            case '2':
               $cols = $check.$edit;
            break;
            case '3':
			case '13':
              if($_GET['flt'] == 'process_list'){
                $cols = $quality_check;
              }else{
                $cols = '';
              }
            break;
            case '10':
            case '4':
              if($_GET['flt'] == 'process_list'){
                $cols = '';
              }else{
                $cols = $anti_check.$cancel;
              }
            break;
            case '5':
            case '6':
            case '7':
                $cols = '';
            break;
            case '8':
               $cols = <<<EOF
            <a href="index.php?app=ome&ctl=admin_return_sv&act=recheck&p[0]={$row['reship_id']}&finder_id={$_GET['_finder']['finder_id']}">重新质检</a>
EOF;
            break;
            case '9':
              if($_GET['flt'] == 'process_list'){
                $cols = '';
              }else{
                $cols = $edit.$cancel.$doback;
              }
            break;
            case '11':
                $cols = $edit.$cancel;
                break;
            default:
               $cols = 'wrong';
        }
        return $cols;
    }

    public function row_style($row) {
        $s = kernel::single('ome_reship')->is_precheck_reship($row['is_check'],$row[$this->col_prefix.'need_sv']);
        return $s ? 'highlight-row' : '';
    }

    var $column_order_id='订单号';
    var $column_order_id_width='100';
    function column_order_id($row){
        $archive = $row[$this->col_prefix . 'archive'];
        $source = $row[$this->col_prefix . 'source'];
        $order_id = $row[$this->col_prefix . 'order_id'];
        $filter = array('order_id'=>$order_id);
        if ($archive == '1' || in_array($source,array('archive'))) {
            $archive_ordObj = kernel::single('archive_interface_orders');
            $order = $archive_ordObj->getOrders($filter,'order_bn');
        }else{
            $orderObj = app::get('ome')->model('orders');
            $order = $orderObj->dump($filter,'order_bn');
        }
        return $order['order_bn'];
    }

    var $column_jsrefund_flag = '极速退款';
    var $column_jsrefund_flag_width='80';
    public function column_jsrefund_flag($row){
        $return_id = $row[$this->col_prefix .'return_id'];
        $source = $row[$this->col_prefix .'source'];
        $db = kernel::database();
        if ($source == 'matrix' && $return_id){
            $data = $db->selectrow("SELECT jsrefund_flag FROM sdb_ome_return_product_tmall WHERE return_id=".$return_id);
            $jsrefund_flag = $data['jsrefund_flag']=='true' ? '是' : '否';
            return $jsrefund_flag;
        }else{
            return '否';
        }
    }
}

?>

==> patch-4.1.7-ONex-OMS-pro-source-PHP5.3.tar.gz: ShopexErp/app/ome/lib/finder/reship.php <==
<?php
class ome_finder_reship{
    function __construct($app){
        $this->app = $app;
        if($_GET['app'] == 'console' ){
            unset($this->column_edit);
        }
    }
    var $addon_cols = 'need_sv,is_check,archive,source,order_id,changebranch_id,return_id,return_type,change_order_id,shop_type';

    var $detail_basic = "退货单详情";

    public static $change_order = array();
    function detail_basic($reship_id){
        $basicMaterialExtObj = app::get('material')->model('basic_material_ext');
        $render = app::get('ome')->render();
        $oReship = app::get('ome')->model('reship');
        $detail = $oReship->getCheckinfo($reship_id);

        $oDesktop          = app::get('desktop')->model('users');
        $desktop_detail    = $oDesktop->dump(array('user_id'=>$detail['op_id']), 'name');
        $detail['op_name'] = $desktop_detail['name'];

        if($detail['is_check'] == '3') $detail['is_check'] = '1';

        $cols = $oReship->_columns();
        $detail['is_check'] = $cols['is_check']['type'][$detail['is_check']];

        $reason = unserialize($detail['reason']);
        $detail['check_memo'] = $reason['check'];

        # 售后问题类型
        if ($detail['problem_id']) {
            $detail['problem_name'] = app::get('ome')->model('return_product_problem')->getCatName($detail['problem_id']);
        }
        
        //退回物流信息
        $return_id    = $detail['return_id'];
        if($return_id && empty($detail['return_logi_id']))
        {
            $oDly_corp    = app::get('ome')->model('dly_corp');
            $reProductObj    = app::get('ome')->model('return_product');
            $product_detail  = $reProductObj->dump(array('return_id'=>$return_id), 'process_data');
            $process_data    = ($product_detail['process_data'] ? unserialize($product_detail['process_data']) : '');
            
            if($process_data)
            {
                $corpinfo = $oDly_corp->dump(array('name'=>$process_data['shipcompany']), 'corp_id');

                //$detail['return_logi_id']    = $corpinfo['corp_id'];
                $detail['return_logi_no']    = $process_data['logino'];
            }
        }
        
        $render->pagedata['detail'] = $detail;

        #[换货]关联的销售物料的类型
        if($detail['return_type'] == 'change'){
            $reshipObjects    = app::get('ome')->model('reship_objects');
            $temp_data    = $reshipObjects->getList('obj_id, obj_type', array('reship'=>$reship_id));
            $reship_objects    = array();
            if($temp_data){
                foreach ($temp_data as $key => $val){
                    $reship_objects[$val['obj_id']]    = $val['obj_type'];
                }
            }
            unset($temp_data);
        }

        #退换货明细
        $reship_item = $oReship->getItemList($reship_id);
        foreach ($reship_item as $key => $value){
            $spec_info    = $basicMaterialExtObj->dump(array('bm_id'=>$value['product_id']), '*');
            $reship_item[$key]['spec_info'] = $spec_info['specifications'];
            $reship_item[$key]['specifications'] = $spec_info['specifications'];
            #换货的销售物料类型
            if($value['obj_id']){
                $reship_item[$key]['item_type']    = $reship_objects[$value['obj_id']];
            }
            $recover[$value['return_type']][] = $reship_item[$key];
        }

        $is_hqepay_on =  app::get('ome')->getConf('ome.delivery.hqepay');
        if($is_hqepay_on == 'false'){
            $is_hqepay_on = false;
        }else{
            $is_hqepay_on = true;
        }

        $render->pagedata['is_hqepay_on'] = $is_hqepay_on;
        $render->pagedata['items'] = $recover;
        return $render->fetch('admin/reship/detail.html');
    }

    var $detail_log = "操作日志";
    function detail_log($reship_id){
        $render = app::get('ome')->render();
        $oOperation_log = app::get('ome')->model('operation_log');
        $render->pagedata['log'] = $oOperation_log->read_log(array('obj_type'=>'reship@ome','obj_id'=>$reship_id),0,20,'log_id desc');
        return $render->fetch('admin/reship/detail_log.html');
    }

    var $detail_acceptreturned = "收货记录";
    function detail_acceptreturned($reship_id){
        $render = app::get('ome')->render();
        $Oreship = app::get('ome')->model('reship');
        $Oreturn_process = app::get('ome')->model('return_process');
        $return = $Oreturn_process->getList('process_data',array('reship_id'=>$reship_id));
        $process_data = unserialize($return[0]['process_data']);
        $process_data['shipdaofu'] = $process_data['shipdaofu']==1?'是':'否';
        if($process_data['shipcompany']){
            $oDc = app::get('ome')->model('dly_corp');
            $dc_data = $oDc->dump($process_data['shipcompany']);
            $process_data['shipcompany'] = !empty($dc_data['name'])?$dc_data['name']:'';
        }
        $Oreason = $Oreship->dump(array('reship_id'=>$reship_id),'reason');
        $Oreason['reason'] = unserialize($Oreason['reason']);
        $p = strpos($Oreason['reason'],'#收货原因#');

        if($p!==false){
           $reason = str_replace('#收货原因#','',$Oreason['reason']);
           $process_data['refuse_memo'] = $reason;
        }

        $render->pagedata['detail'] = $process_data;
        return $render->fetch('admin/reship/detail_acceptreturned.html');
    }

    var $detail_returnedsv = "质检记录";
    function detail_returnedsv($reship_id){
        $render = app::get('ome')->render();
        $Oreship = app::get('ome')->model('reship');
        $Oreturn_process = app::get('ome')->model('return_process');
        $oProblem = app::get('ome')->model('return_product_problem');
        $oBranch = app::get('ome')->model('branch');

        $return = $Oreturn_process->getList('process_data,memo',array('reship_id'=>$reship_id));

        $Oreturn_process_items = app::get('ome')->model('return_process_items');
        $process_items = $Oreturn_process_items->getList('bn,memo,store_type,branch_id,num',array('is_check'=>'true','reship_id'=>$reship_id));

        $process_data = unserialize($return[0]['process_data']);
        $process_data['shipdaofu'] = $process_data['shipdaofu']==1?'是':'否';
        $Oreason = $Oreship->dump(array('reship_id'=>$reship_id),'reason,is_check,need_sv');

        $process_data['reason'] = unserialize($Oreason['reason']);

        foreach($process_items as $k=>$v){
           $process_items[$k]['store_type'] = $oProblem->get_store_type($process_items[$k]['store_type']);
           $branch = $oBranch->db->selectrow("SELECT name from sdb_ome_branch WHERE branch_id=".$process_items[$k]['branch_id']);
           $process_items[$k]['branch_id'] = $branch['name'];
        }

        $render->pagedata['memo'] = $return[0]['memo'];
        $render->pagedata['process_items'] = $process_items;
        $render->pagedata['detail'] = $process_data;

        $s = kernel::single('ome_reship')->is_precheck_reship($Oreason['is_check'],$Oreason['need_sv']);
        if ($s) {
            $render->pagedata['memo'] = '质检异常';
        }

        return $render->fetch('admin/reship/detail_returnsv.html');
    }


    var $column_edit = "操作";
    var $column_edit_width = "200";
    function column_edit($row){
        $oReship = app::get('ome')->model('reship');
        $reship_items= $oReship->dump($row['reship_id'],'reship_bn,source,return_type,return_id,change_order_id,change_status');
        //判断来源是天猫且类型为换货才可以有换货提前生成按钮
        $is_check = $row[$this->col_prefix.'is_check'];
		if ($is_check == '11' || $is_check=='9'){
			$edit_title = '最终收货';
		}else{
			$edit_title = '编辑';
		}
        $precheck = kernel::single('ome_reship')->is_precheck_reship($row[$this->col_prefix.'is_check'],$row[$this->col_prefix.'need_sv']);

        $check = '<a target="dialog::{width:1200,height:546,title:\'审核退换货单号:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=check&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">'.($precheck ? '最终收货' : '审核').'</a>  ';

        $anti_check = '  <a target="dialog::{width:250,height:100,title:\'反审核退换货单号:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=anti_check&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">反审核</a>  ';

        $edit ='  <a target="dialog::{width:1200,height:546,title:\'编辑退换货单:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=edit&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">'.$edit_title.'</a>  ';

        $accept_returned = '  <a target="dialog::{width:1200,height:546,title:\'收货退换货单:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=accept_returned&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">收货</a>  ';

        $cancel = '  <a target="dialog::{width:280,height:100,title:\'取消退换货单号:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=do_cancel&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">取消</a>  ';

        $doback = '  <a target="dialog::{width:280,height:100,title:\'退换货单号:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_rchange&act=do_back&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">退回</a>';

        $quality_check = '  <a target="dialog::{width:1200,height:546,title:\'质检退换货单:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_return_sv&act=edit&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">收货/质检</a>';
        $change_orderBtn = '';
        if ($reship_items['return_type'] == 'change'){
            $tmall_detail = kernel::single('ome_service_aftersale')->get_return_type(array('return_id'=>$reship_items['return_id']));
            if ($tmall_detail['refund_type'] == 'change'){
                if($reship_items['change_order_id']==0 && $reship_items['change_status']=='0'){
                    $change_orderBtn = '  <a target="dialog::{width:400,height:200,title:\'换货订单:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_reship&act=create_change_order&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">换货订单</a>';
                }

                //if($is_check == '0'){
                    //天猫换货取消按钮。要重新
                    $cancel = '  <a target="dialog::{width:600,height:400,title:\'取消退换货单号:'.$reship_items['reship_bn'].'\'}" href="index.php?app=ome&ctl=admin_reship&act=refuse_message&p[0]='.$row['reship_id'].'&finder_id='.$_GET['_finder']['finder_id'].'">取消</a>  ';
                //}

            }

        }
        if($is_check == '1' && $tmall_detail['refund_type'] == 'change'){
           // $cancel = '';//已审核且已生成换货订单不允许取消
        }

       $permissions = array(
            'check'         => 'aftersale_rchange_check',
            'anti_check'    => 'aftersale_rchange_recheck',
            'edit'          => 'aftersale_rchange_edit',
            'cancel'        => 'aftersale_rchange_refuse',
            'doback'        => 'aftersale_rchange_back',
            'quality_check' => 'aftersale_rchange_sv',

       );
        if(!kernel::single('desktop_user')->is_super()){
            $returnLib = kernel::single('ome_return');
            foreach ($permissions as $key=>$permission) {
                $has_permission = $returnLib->chkground('aftersale_center','',$permission);
                // $has_permission = kernel::single('desktop_user')->has_permission($permission);
                if (!$has_permission) {
                    $$key = '';
                }
            }
        }

        switch($row[$this->col_prefix.'is_check']){
            case '0':
			case '12':
               $cols = $check.$edit.$cancel;
            break;
            case '1':
              if($_GET['flt'] == 'process_list'){
                $cols = $quality_check;
              }else{
                $cols.=$cancel.$change_orderBtn;
              }
            break;
            case '2':
               $cols = $check.$edit;
            break;
            case '3':
			case '13':
              if($_GET['flt'] == 'process_list'){
                $cols = $quality_check;
              }else{
                $cols = '';
              }
            break;
            case '10':
            case '4':
              if($_GET['flt'] == 'process_list'){
                $cols = '';
              }else{
                $cols = $anti_check.$cancel;
              }
            break;
            case '5':
            case '6':
            case '7':
                $cols = '';
            break;
            case '8':
               $cols = <<<EOF
            <a href="index.php?app=ome&ctl=admin_return_sv&act=recheck&p[0]={$row['reship_id']}&finder_id={$_GET['_finder']['finder_id']}">重新质检</a>
EOF;
            break;
            case '9':
              if($_GET['flt'] == 'process_list'){
                $cols = '';
              }else{
                $cols = $edit.$cancel.$doback;
              }
            break;
            case '11':
                $cols = $edit.$cancel;
                break;
            default:
               $cols = 'wrong';
        }
        return $cols;
    }

    public function row_style($row) {
        $s = kernel::single('ome_reship')->is_precheck_reship($row['is_check'],$row[$this->col_prefix.'need_sv']);
        $style = '';

        if ($s){
            $style.= 'highlight-row';
        }
        if ($row[$this->col_prefix.'source'] == 'matrix' && $row[$this->col_prefix.'return_type'] == 'change'){
            $style.= 'selected';
        }
        return $style;
    }

    var $column_order_id='订单号';
    var $column_order_id_width='100';
    function column_order_id($row)
    {
        $archive = $row[$this->col_prefix . 'archive'];
        $source = $row[$this->col_prefix . 'source'];
        $order_id = $row[$this->col_prefix . 'order_id'];
        $filter = array('order_id'=>$order_id);
        if ($archive == '1' || in_array($source,array('archive'))) {
            $archive_ordObj = kernel::single('archive_interface_orders');
            $order = $archive_ordObj->getOrders($filter,'order_bn');
        }else{
            $orderObj = app::get('ome')->model('orders');
            $order = $orderObj->dump($filter,'order_bn');
        }

        return $order['order_bn'];
    }


    var $column_changebranch_id = '换货仓';
    var $column_changebranch_id_width='80';
    function column_changebranch_id($row){
        $changebranch_id = $row[$this->col_prefix .'changebranch_id'];

        if($changebranch_id){
            $branchObj = app::get('ome')->model('branch');
            $branch = $branchObj->db->selectrow('select name FROM sdb_ome_branch WHERE branch_id='.$changebranch_id);
            return $branch['name'];
        }else{
            return '-';
        }
    }

    var $column_jsrefund_flag = '极速退款';
    var $column_jsrefund_flag_width='80';
    public function column_jsrefund_flag($row){
        $return_id = $row[$this->col_prefix .'return_id'];
        $source = $row[$this->col_prefix .'source'];
        $db = kernel::database();
        if ($source == 'matrix' && $return_id){
            $data = $db->selectrow("SELECT jsrefund_flag FROM sdb_ome_return_product_tmall WHERE return_id=".$return_id);
            $jsrefund_flag = $data['jsrefund_flag']=='true' ? '是' : '否';
            return $jsrefund_flag;
        }else{
            return '否';
        }
    }

    var $column_change_order_id = '换货订单号';
    var $column_change_order_id_width='80';
    public function column_change_order_id($row){
        $change_order_id = $row[$this->col_prefix .'change_order_id'];
        if ($change_order_id){

            if (self::$change_order[$change_order_id]){
                return self::$change_order[$change_order_id];
            }else{
                $orderObj = app::get('ome')->model('orders');
                $order_detail = $orderObj->dump(array('order_id'=>$change_order_id),'order_bn');
                self::$change_order[$change_order_id] = $order_detail['order_bn'];
                return self::$change_order[$change_order_id];
            }
        }

    }

    var $column_time_out = '超时时间';
    var $column_time_out_width='120';
    function column_time_out($row){

        if ($row[$this->col_prefix.'source'] == 'matrix' && $row[$this->col_prefix.'shop_type']=='tmall' && $row[$this->col_prefix.'return_type'] == 'change'){
            $tmallObj = app::get('ome')->model('return_product_tmall');
            $tmall_detail = $tmallObj->dump(array('return_id'=>$row['return_id'],'refund_type'=>'change'),'current_phase_timeout');
            if ($tmall_detail && $tmall_detail['current_phase_timeout']){
               return "<div style='width:120px;height:20px;background-color:green;color:#FFFFFF;text-align:center;'>".date('Y-m-d H:i:s',$tmall_detail['current_phase_timeout'])."</div>";;
            }

        }else{
            return '-';
        }

    }
}

?>
